hgext/split.py
changeset 46843 728d89f6f9b1
parent 46758 7f6c002d7c0a
child 46923 8ee1ac083ee7
--- a/hgext/split.py	Tue Mar 30 02:33:12 2021 +0200
+++ b/hgext/split.py	Tue Mar 30 02:32:30 2021 +0200
@@ -12,7 +12,7 @@
 from mercurial.i18n import _
 
 from mercurial.node import (
-    nullid,
+    nullrev,
     short,
 )
 
@@ -80,12 +80,12 @@
                 raise error.InputError(_(b'cannot split multiple revisions'))
 
             rev = revs.first()
-            ctx = repo[rev]
-            # Handle nullid specially here (instead of leaving for precheck()
+            # Handle nullrev specially here (instead of leaving for precheck()
             # below) so we get a nicer message and error code.
-            if rev is None or ctx.node() == nullid:
+            if rev is None or rev == nullrev:
                 ui.status(_(b'nothing to split\n'))
                 return 1
+            ctx = repo[rev]
             if ctx.node() is None:
                 raise error.InputError(_(b'cannot split working directory'))